ResponsiveUtils class

A robust responsive utility for Flutter that provides hybrid scaling.

It combines screen width, height, and device pixel ratio (DPI) to calculate optimal scaling for different device types like mobile, tablet, and desktop.

Use ResponsiveUtils.init to initialize, though it also auto-initializes on first use via SizeManager.

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

didChangeAccessibilityFeatures() → void
Called when the system changes the set of currently active accessibility features.
inherited
didChangeAppLifecycleState(AppLifecycleState state) → void
Called when the system puts the app in the background or returns the app to the foreground.
override
didChangeLocales(List<Locale>? locales) → void
Called when the system tells the app that the user's locale has changed. For example, if the user changes the system language settings.
inherited
didChangeMetrics() → void
Called when the application's dimensions change. For example, when a phone is rotated.
override
didChangePlatformBrightness() → void
Called when the platform brightness changes.
inherited
didChangeTextScaleFactor() → void
Called when the platform's text scale factor changes.
inherited
didChangeViewFocus(ViewFocusEvent event) → void
Called whenever the PlatformDispatcher receives a notification that the focus state on a view has changed.
inherited
didHaveMemoryPressure() → void
Called when the system is running low on memory.
inherited
didPopRoute() Future<bool>
Called when the system tells the app to pop the current route, such as after a system back button press or back gesture.
inherited
didPushRoute(String route) Future<bool>
Called when the host tells the application to push a new route onto the navigator.
inherited
didPushRouteInformation(RouteInformation routeInformation) Future<bool>
Called when the host tells the application to push a new RouteInformation and a restoration state onto the router.
inherited
didRequestAppExit() Future<AppExitResponse>
Called when a request is received from the system to exit the application.
inherited
handleCancelBackGesture() → void
Called when a predictive back gesture is canceled, indicating that no navigation should occur.
inherited
handleCommitBackGesture() → void
Called when a predictive back gesture is finished successfully, indicating that the current route should be popped.
inherited
handleStartBackGesture(PredictiveBackEvent backEvent) bool
Called at the start of a predictive back gesture.
inherited
handleStatusBarTap() → void
Called when the user taps the status bar on iOS, to scroll a scroll view to the top.
inherited
handleUpdateBackGestureProgress(PredictiveBackEvent backEvent) → void
Called when a predictive back gesture moves.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

blockSizeHorizontal double
1% of the screen width.
getter/setter pair
blockSizeVertical double
1% of the screen height.
getter/setter pair
instance ResponsiveUtils
Gets the singleton instance of ResponsiveUtils.
no setter
safeAreaBottom double
Height of the bottom safe area (e.g., home indicator).
getter/setter pair
safeAreaLeft double
Width of the left safe area.
getter/setter pair
safeAreaRight double
Width of the right safe area.
getter/setter pair
safeAreaTop double
Height of the top safe area (e.g., status bar, notch).
getter/setter pair
safeBlockHorizontal double
1% of the safe (usable) screen width.
getter/setter pair
safeBlockVertical double
1% of the safe (usable) screen height.
getter/setter pair
screenHeight double
Current screen height in logical pixels.
getter/setter pair
screenWidth double
Current screen width in logical pixels.
getter/setter pair

Static Methods

font(double inputFont) double
Calculates a scaled font size, tuned for readability across devices.
height(double inputHeight) double
Calculates a scaled height value.
init({BuildContext? context}) → void
Initializes the responsive utility.
width(double inputWidth) double
Calculates a scaled width value.