isDesktop property
bool
get
isDesktop
Returns true if the device is a desktop or laptop (>= 1200dp width).
Implementation
static bool get isDesktop => screenWidth >= 1200;
Returns true if the device is a desktop or laptop (>= 1200dp width).
static bool get isDesktop => screenWidth >= 1200;