isMobile property
bool
get
isMobile
Returns true if the device is a mobile phone (< 600dp width).
Implementation
static bool get isMobile => screenWidth < 600;
Returns true if the device is a mobile phone (< 600dp width).
static bool get isMobile => screenWidth < 600;