isTablet property
bool
get
isTablet
Returns true if the device is a tablet (600dp - 1200dp width).
Implementation
static bool get isTablet => screenWidth >= 600 && screenWidth < 1200;
Returns true if the device is a tablet (600dp - 1200dp width).
static bool get isTablet => screenWidth >= 600 && screenWidth < 1200;